@@ -10,6 +10,8 @@ class AlipayCommerceEcEmployeeInfoQueryModel(object):
     def __init__(self):
         self._employee_id = None
         self._enterprise_id = None
+        self._open_id = None
+        self._user_id = None
 
     @property
     def employee_id(self):
@@ -25,6 +27,20 @@ class AlipayCommerceEcEmployeeInfoQueryModel(object):
     @enterprise_id.setter
     def enterprise_id(self, value):
         self._enterprise_id = value
+    @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
+    def user_id(self):
+        return self._user_id
+
+    @user_id.setter
+    def user_id(self, value):
+        self._user_id = value
 
 
     def to_alipay_dict(self):
@@ -39,6 +55,16 @@ class AlipayCommerceEcEmployeeInfoQueryModel(object):
                 params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
             else:
                 params['enterprise_id'] = self.enterprise_id
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
+        if self.user_id:
+            if hasattr(self.user_id, 'to_alipay_dict'):
+                params['user_id'] = self.user_id.to_alipay_dict()
+            else:
+                params['user_id'] = self.user_id
         return params
 
     @staticmethod
@@ -50,6 +76,10 @@ class AlipayCommerceEcEmployeeInfoQueryModel(object):
             o.employee_id = d['employee_id']
         if 'enterprise_id' in d:
             o.enterprise_id = d['enterprise_id']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
+        if 'user_id' in d:
+            o.user_id = d['user_id']
         return o
 
 
