@@ -47,6 +47,7 @@ class AssetDeliveryItem(object):
         self._supplier_id = None
         self._supplier_name = None
         self._to_address = None
+        self._work_process = None
 
     @property
     def action_type(self):
@@ -305,6 +306,13 @@ class AssetDeliveryItem(object):
             self._to_address = value
         else:
             self._to_address = AssetDeliveryAddress.from_alipay_dict(value)
+    @property
+    def work_process(self):
+        return self._work_process
+
+    @work_process.setter
+    def work_process(self, value):
+        self._work_process = value
 
 
     def to_alipay_dict(self):
@@ -484,6 +492,11 @@ class AssetDeliveryItem(object):
                 params['to_address'] = self.to_address.to_alipay_dict()
             else:
                 params['to_address'] = self.to_address
+        if self.work_process:
+            if hasattr(self.work_process, 'to_alipay_dict'):
+                params['work_process'] = self.work_process.to_alipay_dict()
+            else:
+                params['work_process'] = self.work_process
         return params
 
     @staticmethod
@@ -561,6 +574,8 @@ class AssetDeliveryItem(object):
             o.supplier_name = d['supplier_name']
         if 'to_address' in d:
             o.to_address = d['to_address']
+        if 'work_process' in d:
+            o.work_process = d['work_process']
         return o
 
 
