@@ -13,6 +13,8 @@ class EcConsumeInfo(object):
         self._biz_out_no = None
         self._category_name = None
         self._consume_amount = None
+        self._consume_category = None
+        self._consume_memo = None
         self._consume_type = None
         self._employee_id = None
         self._enterprise_id = None
@@ -27,6 +29,7 @@ class EcConsumeInfo(object):
         self._invoice_open_mode = None
         self._merchant_id = None
         self._merchant_name = None
+        self._open_id = None
         self._order_complete_label = None
         self._order_complete_time = None
         self._pay_no = None
@@ -78,6 +81,20 @@ class EcConsumeInfo(object):
     def consume_amount(self, value):
         self._consume_amount = value
     @property
+    def consume_category(self):
+        return self._consume_category
+
+    @consume_category.setter
+    def consume_category(self, value):
+        self._consume_category = value
+    @property
+    def consume_memo(self):
+        return self._consume_memo
+
+    @consume_memo.setter
+    def consume_memo(self, value):
+        self._consume_memo = value
+    @property
     def consume_type(self):
         return self._consume_type
 
@@ -176,6 +193,13 @@ class EcConsumeInfo(object):
     def merchant_name(self, value):
         self._merchant_name = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def order_complete_label(self):
         return self._order_complete_label
 
@@ -302,6 +326,16 @@ class EcConsumeInfo(object):
                 params['consume_amount'] = self.consume_amount.to_alipay_dict()
             else:
                 params['consume_amount'] = self.consume_amount
+        if self.consume_category:
+            if hasattr(self.consume_category, 'to_alipay_dict'):
+                params['consume_category'] = self.consume_category.to_alipay_dict()
+            else:
+                params['consume_category'] = self.consume_category
+        if self.consume_memo:
+            if hasattr(self.consume_memo, 'to_alipay_dict'):
+                params['consume_memo'] = self.consume_memo.to_alipay_dict()
+            else:
+                params['consume_memo'] = self.consume_memo
         if self.consume_type:
             if hasattr(self.consume_type, 'to_alipay_dict'):
                 params['consume_type'] = self.consume_type.to_alipay_dict()
@@ -372,6 +406,11 @@ class EcConsumeInfo(object):
                 params['merchant_name'] = self.merchant_name.to_alipay_dict()
             else:
                 params['merchant_name'] = self.merchant_name
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.order_complete_label:
             if hasattr(self.order_complete_label, 'to_alipay_dict'):
                 params['order_complete_label'] = self.order_complete_label.to_alipay_dict()
@@ -459,6 +498,10 @@ class EcConsumeInfo(object):
             o.category_name = d['category_name']
         if 'consume_amount' in d:
             o.consume_amount = d['consume_amount']
+        if 'consume_category' in d:
+            o.consume_category = d['consume_category']
+        if 'consume_memo' in d:
+            o.consume_memo = d['consume_memo']
         if 'consume_type' in d:
             o.consume_type = d['consume_type']
         if 'employee_id' in d:
@@ -487,6 +530,8 @@ class EcConsumeInfo(object):
             o.merchant_id = d['merchant_id']
         if 'merchant_name' in d:
             o.merchant_name = d['merchant_name']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'order_complete_label' in d:
             o.order_complete_label = d['order_complete_label']
         if 'order_complete_time' in d:
