@@ -3,6 +3,7 @@
 import json
 
 from alipay.aop.api.response.AlipayResponse import AlipayResponse
+from alipay.aop.api.domain.AnswerDTO import AnswerDTO
 from alipay.aop.api.domain.TemplateInstDTO import TemplateInstDTO
 
 
@@ -10,10 +11,21 @@ class AlipayFincoreComplianceTemplateInstanceQueryResponse(AlipayResponse):
 
     def __init__(self):
         super(AlipayFincoreComplianceTemplateInstanceQueryResponse, self).__init__()
+        self._answers = None
         self._status = None
         self._template_instances = None
 
     @property
+    def answers(self):
+        return self._answers
+
+    @answers.setter
+    def answers(self, value):
+        if isinstance(value, AnswerDTO):
+            self._answers = value
+        else:
+            self._answers = AnswerDTO.from_alipay_dict(value)
+    @property
     def status(self):
         return self._status
 
@@ -33,6 +45,8 @@ class AlipayFincoreComplianceTemplateInstanceQueryResponse(AlipayResponse):
 
     def parse_response_content(self, response_content):
         response = super(AlipayFincoreComplianceTemplateInstanceQueryResponse, self).parse_response_content(response_content)
+        if 'answers' in response:
+            self.answers = response['answers']
         if 'status' in response:
             self.status = response['status']
         if 'template_instances' in response:
