@@ -11,6 +11,7 @@ class ZhimaCreditPeZmgoPreConsultResponse(AlipayResponse):
         super(ZhimaCreditPeZmgoPreConsultResponse, self).__init__()
         self._admittance = None
         self._alipay_user_id = None
+        self._open_id = None
 
     @property
     def admittance(self):
@@ -26,6 +27,13 @@ class ZhimaCreditPeZmgoPreConsultResponse(AlipayResponse):
     @alipay_user_id.setter
     def alipay_user_id(self, value):
         self._alipay_user_id = value
+    @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
 
     def parse_response_content(self, response_content):
         response = super(ZhimaCreditPeZmgoPreConsultResponse, self).parse_response_content(response_content)
@@ -33,3 +41,5 @@ class ZhimaCreditPeZmgoPreConsultResponse(AlipayResponse):
             self.admittance = response['admittance']
         if 'alipay_user_id' in response:
             self.alipay_user_id = response['alipay_user_id']
+        if 'open_id' in response:
+            self.open_id = response['open_id']
